package com.tencent.tic.core;

import android.content.Context;
import android.util.Log;

import com.tencent.imsdk.v2.V2TIMCallback;
import com.tencent.imsdk.v2.V2TIMConversation;
import com.tencent.imsdk.v2.V2TIMGroupInfo;
import com.tencent.imsdk.v2.V2TIMManager;
import com.tencent.imsdk.v2.V2TIMMessage;
import com.tencent.imsdk.v2.V2TIMSDKConfig;
import com.tencent.imsdk.v2.V2TIMSDKListener;
import com.tencent.imsdk.v2.V2TIMSendCallback;
import com.tencent.imsdk.v2.V2TIMValueCallback;
import com.tencent.teduboard.TEduBoardController;
import com.tencent.tic.demo.R;

import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class IMManager {
    private int mSdkAppID;
    private String mUserId = "";
    private String mUserSig = "";
    private String mClassId = "";
    private boolean mIsLogin;
    protected List<WeakReference<TIMCallBack>> mCallBacks = new ArrayList<WeakReference<TIMCallBack>>();

    private static volatile IMManager instance;
    private static final byte[] SYNC = new byte[1];

    public static IMManager getInstance() {
        if (instance == null) {
            synchronized (SYNC) {
                if (instance == null) {
                    instance = new IMManager();
                }
            }
        }
        return instance;
    }
    // IM初始化
    public boolean initSDK(Context context, final int sdkAppID) {
        V2TIMSDKConfig timSdkConfig = new V2TIMSDKConfig();
        boolean result = V2TIMManager.getInstance().initSDK(context, sdkAppID, timSdkConfig);
        V2TIMManager.getInstance().addIMSDKListener(new IMSDKListener());
        return result;
    }


    public void addCallback(TIMCallBack callback) {
        for (WeakReference<TIMCallBack> listener : mCallBacks) {
            TIMCallBack t = listener.get();
            if (t != null && t.equals(callback)) {
                return;
            }
        }
        WeakReference<TIMCallBack> weaklistener = new WeakReference<TIMCallBack>(callback);
        mCallBacks.add(weaklistener);
    }

    public void removeCallback(TIMCallBack callback) {
        Iterator<WeakReference<TIMCallBack>> it = mCallBacks.iterator();
        while (it.hasNext()) {
            TIMCallBack t = it.next().get();
            if (t != null && t.equals(callback)) {
                it.remove();
                break;
            }
        }
    }
    // 销毁IM资源
    public void unInitSDK() {
        V2TIMManager.getInstance().unInitSDK();
    }

    // IM登录
    public void login(final String userId, final String userSig, final IMCallBack callBack) {
        if (mIsLogin) {
            if (callBack != null) {
                callBack.onComplete(-1, String.format(TextUtil.getString(R.string.user_already_logged_in), mUserId));
            }
            return;
        }
        V2TIMManager.getInstance().login(userId, userSig, new V2TIMCallback() {
            @Override
            public void onSuccess() {
                mUserId = userId;
                mUserSig = userSig;
                mIsLogin = true;
                if (callBack != null) {
                    callBack.onComplete(0, "");
                }
            }

            @Override
            public void onError(int errCode, String errMsg) {
                if (callBack != null) {
                    callBack.onComplete(errCode, errMsg);
                }
            }
        });
    }

    // IM登出
    public void logout(final IMCallBack callBack) {
        V2TIMManager.getInstance().logout(new V2TIMCallback(){
            @Override
            public void onSuccess() {
                mClassId = "";
                mIsLogin = false;
                if (callBack != null) {
                    callBack.onComplete(0, "");
                }
            }

            @Override
            public void onError(int errCode, String errMsg) {
                if (callBack != null) {
                    callBack.onComplete(errCode, errMsg);
                }
            }
        });
    }

    // IM被踢
    public void kickout() {
        mClassId = "";
        mIsLogin = false;
    }

    // 创建IM群组
    public void createIMGroup(final String classId, final IMCallBack callBack) {
        V2TIMGroupInfo groupInfo = new V2TIMGroupInfo();
        groupInfo.setGroupID(classId);
        groupInfo.setGroupName(classId);
        groupInfo.setGroupType("Public");
        groupInfo.setIntroduction("this is a test Work group");
        groupInfo.setGroupAddOpt(2);
        V2TIMManager.getGroupManager().createGroup(groupInfo, null, new V2TIMValueCallback<String>() {
            @Override
            public void onError(int errCode, String errMsg) {
                if (null != callBack) {
                    callBack.onComplete(errCode,errMsg);
                }
            }

            @Override
            public void onSuccess(String s) {
                if (null != callBack) {
                    callBack.onComplete(0,"");
                }
            }
        });
    }

    // 加入IM群组（含创建IM群组逻辑）
    public void joinIMGroup(final String classId, final IMCallBack callBack) {
        if (mClassId.length() > 0) {
            if (classId.equals(mClassId)) {
                if (null != callBack) {
                    callBack.onComplete(0,"");
                }
            }
            else {
                // 先退出群组，再加入新群组
                this.quitIMGroup(mClassId, new IMCallBack() {
                    @Override
                    public void onComplete(int errCode, String errMsg) {
                        joinIMGroup(classId, callBack);
                    }
                });
            }
            return;
        }
        this.createIMGroup(classId, new IMCallBack() {
            @Override
            public void onComplete(int errCode, String errMsg) {
                // 0表示IM群组创建成功，10021和10025表示群组已存在
                if (errCode == 0 || errCode == 10021 || errCode == 10025) {
                    V2TIMManager.getInstance().joinGroup(classId, "board group" + classId, new V2TIMCallback() {
                        @Override
                        public void onSuccess() {
                            mClassId = classId;
                            if (null != callBack) {
                                callBack.onComplete(0,"");
                            }
                        }

                        @Override
                        public void onError(int i, String s) {
                            if (i == 10013) {
                                // 已经在群中
                                mClassId = classId;
                                if (null != callBack) {
                                    callBack.onComplete(0,"");
                                }
                            }
                            else {
                                if (null != callBack) {
                                    callBack.onComplete(i, s);
                                }
                            }
                        }
                    });
                }
                else {
                    if (null != callBack) {
                        callBack.onComplete(errCode, errMsg);
                    }
                }
            }
        });
    }

    // 销毁群组
    public void destroyIMGroup(final String classId, final IMCallBack callBack) {
        V2TIMManager.getInstance().dismissGroup(classId, new V2TIMCallback() {

            @Override
            public void onSuccess() {
                mClassId = "";
                if (callBack != null) {
                    callBack.onComplete(0, "");
                }
            }

            @Override
            public void onError(int i, String s) {
                if (null != callBack) {
                    callBack.onComplete(i, s);
                }
            }
        });
    }
    // 退出IM群组
    public void quitIMGroup(final String classId, final IMCallBack callBack) {
        V2TIMManager.getInstance().quitGroup(classId, new V2TIMCallback() {
            @Override
            public void onSuccess() {
                mClassId = "";
                if (callBack != null) {
                    callBack.onComplete(0, "");
                }
            }

            @Override
            public void onError(int i, String s) {
                if (i == 10009) {
                    //群主退群失败
                    mClassId = "";
                    if (callBack != null) {
                        callBack.onComplete(0, "");
                    }
                }
                else{
                    if (null != callBack) {
                        callBack.onComplete(i, s);
                    }
                }
            }
        });
    }

    public void sendCustomMsg(String data) {
        final String groupID = "" + this.mClassId;
        final V2TIMMessage message = V2TIMManager.getMessageManager().createCustomMessage(data.getBytes(), "", "TXWhiteBoardExt".getBytes());
        if (message.getCustomElem() != null) {
            message.getCustomElem().setExtension("TXWhiteBoardExt".getBytes());
        }
        V2TIMManager.getConversationManager().getConversation("group_" + groupID, new V2TIMValueCallback<V2TIMConversation>() {
            @Override
            public void onSuccess(V2TIMConversation v2TIMConversation) {
                if (v2TIMConversation.getType() == V2TIMConversation.V2TIM_GROUP) {
                    boolean onlineUserOnly = !(v2TIMConversation.getGroupType().toLowerCase().equals("avchatroom"));
                    V2TIMManager.getMessageManager().sendMessage(message, null, groupID, 1, onlineUserOnly, null,  new V2TIMSendCallback<V2TIMMessage>() {
                        @Override
                        public void onSuccess(V2TIMMessage v2TIMMessage) {
                            // 发送 IM 消息成功
                            Log.i("sendCustomMsg", "sucess");
                        }

                        @Override
                        public void onError(int i, String s) {
                            // 发送 IM 消息失败，建议进行重试
                            Log.i("sendCustomMsg", "onError");
                        }

                        @Override
                        public void onProgress(int i) {

                        }
                    });
                }
            }

            @Override
            public void onError(int i, String s) {
                // 获取回话失败
            }
        });
    }


//- (void)destroyIMGroup
    public interface IMCallBack {
        /**
         * 函数调用结果回调
         *
         * @param errCode 错误码, 0表示成功
         * @param errMsg  错误描述
         */
        void onComplete(int errCode, String errMsg);
    }

    public interface TIMCallBack {
        // 当前用户被踢下线，此时可以重新登录。
        void onTIMForceOffline();

        // 在线时票据过期：此时您需要生成新的 userSig 并重新登录
        void onTIMUserSigExpired();

        // IM掉线
        void onConnectFailed(int code, String error);
    }

    private  class IMSDKListener extends V2TIMSDKListener {
        public void onKickedOffline() {
            IMManager manager = IMManager.getInstance();
            if (manager.mCallBacks != null) {
                Iterator<WeakReference<TIMCallBack>> it = manager.mCallBacks.iterator();
                while (it.hasNext()) {
                    TIMCallBack t = it.next().get();
                    t.onTIMForceOffline();
                }
            }

            manager.mClassId = "";
            manager.mIsLogin = false;
        }

        public void onUserSigExpired() {
            IMManager manager = IMManager.getInstance();
            if (manager.mCallBacks != null) {
                Iterator<WeakReference<TIMCallBack>> it = manager.mCallBacks.iterator();
                while (it.hasNext()) {
                    TIMCallBack t = it.next().get();
                    t.onTIMUserSigExpired();
                }
            }
        }
        public void onConnectFailed(int code, String error) {
            IMManager manager = IMManager.getInstance();
            if (manager.mCallBacks != null) {
                Iterator<WeakReference<TIMCallBack>> it = manager.mCallBacks.iterator();
                while (it.hasNext()) {
                    TIMCallBack t = it.next().get();
                    t.onConnectFailed(code, error);
                }
            }
            manager.mClassId = "";
            manager.mIsLogin = false;

            Log.i("TIIMSDK", "onConnectFailed, code: " + code + ", error:" + error);
        }

        public void onConnecting() {
            Log.i("TIIMSDK", "onConnecting......");
        }

        public void onConnectSuccess() {
            Log.i("TIIMSDK", "onConnectSuccess......");
        }
    }
}

