package com.tencent.tic.demo.activities;

import android.content.Context;
import android.util.Log;
import android.webkit.JavascriptInterface;
import android.widget.FrameLayout;
import android.widget.LinearLayout;

import com.tencent.smtt.sdk.WebSettings;
import com.tencent.smtt.sdk.WebView;
import com.tencent.smtt.sdk.WebViewClient;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;



public class PopWebView extends LinearLayout {
    private final static String TAG = "PopWebView";
    private WebView webView;
    private boolean isPageFinished = false;
    private ArrayList cacheJS = new ArrayList<String>();
    private PopWebViewListener listener;
    public PopWebView(Context context) {
        super(context);
        this.setBackgroundColor(0);
        this.getBackground().setAlpha(0);
        this.webView = new com.tencent.smtt.sdk.WebView(context);
        this.webView.setBackgroundColor(0);
//        this.webView.getBackground().setAlpha(0);
        WebSettings settings = this.webView.getSettings();
        settings.setJavaScriptEnabled(true);
        settings.setCacheMode(WebSettings.LOAD_DEFAULT);
        settings.setDomStorageEnabled(true);
        settings.setDatabaseEnabled(true);
        settings.setAppCacheEnabled(true);
        settings.setAllowFileAccess(true);

        FrameLayout.LayoutParams layout = new FrameLayout.LayoutParams(FrameLayout.LayoutParams.MATCH_PARENT, FrameLayout.LayoutParams.MATCH_PARENT);
        this.addView(this.webView, layout);
        this.webView.setWebViewClient(new WebViewClient() {
            @Override
            public void onPageFinished(WebView webView, String s) {
                super.onPageFinished(webView, s);
                PopWebView ref = PopWebView.this;
                ref.isPageFinished = true;
                for (int i = 0; i < ref.cacheJS.size(); i++) {
                    ref.webView.evaluateJavascript(ref.cacheJS.get(i).toString(), null);
                }
                ref.cacheJS.clear();
            }
        });
        this.webView.addJavascriptInterface(new MyJavaScriptInterface(context), "MyJSCallback");
    }
    public interface PopWebViewListener {
        public void onReceiveH5Msg(JSONObject msg);
    }
    private class MyJavaScriptInterface {
        MyJavaScriptInterface(Context context) {
        }
        @JavascriptInterface
        public void sendMessageToNative(final String msg) {
            try {
                JSONObject jsonObj = new JSONObject(msg);
                PopWebView.this.listener.onReceiveH5Msg(jsonObj);
            } catch (JSONException e) {
                Log.i(TAG, "recivedMsg error: " +  e.toString());
            }
        }
    }

    public void loadUrl(String url) {
        this.webView.loadUrl(url);
    }

    public void sendToH5(String action, JSONObject jsonObj) {
        if (jsonObj == null) {
            jsonObj = new JSONObject();
        }
        String jsonStr = jsonObj.toString();
        this.sendToH5(action, jsonStr);
    }

    public void sendToH5(String action, String jsonStr) {
        String jsStr = String.format("window.reciveMessageFromNative('%s', '%s')", action, jsonStr);
        if (this.isPageFinished) {
            this.webView.evaluateJavascript(jsStr, null);
        } else {
            this.cacheJS.add(jsStr);
        }
    }

    public void setListener(PopWebViewListener listener) {
        this.listener = listener;
    }
}