package com.tencent.tic.demo.activities;

import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.EditText;
import android.widget.FrameLayout;

import com.tencent.smtt.sdk.WebSettings;
import com.tencent.smtt.sdk.WebView;
import com.tencent.smtt.sdk.WebViewClient;
import com.tencent.tic.core.IMManager;
import com.tencent.tic.core.TextUtil;
import com.tencent.tic.demo.R;

import java.util.Locale;
import java.util.Random;


public class TICClassManagerActivity extends BaseActvity {

    // 课堂id
    EditText etRoomIdInput;
    // IM群组
    EditText etImGroupIDInput;
    // nickName
    EditText etNickNameInput;

    WebView mWebView;
    FrameLayout webviewContainer;

    // IM掉线
    @Override
    public void onConnectFailed(int code, String error) {
        finish();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_manager_layout);

        //用户信息
        mUserID = getIntent().getStringExtra(USER_ID);
        mUserSig = getIntent().getStringExtra(USER_SIG);

        mRoomId = resumeFromCache();

        etRoomIdInput = (EditText) findViewById(R.id.et_roomid);
        etImGroupIDInput = (EditText) findViewById(R.id.et_im_group_id);

        etRoomIdInput.setText(String.valueOf(mRoomId));

        etNickNameInput = (EditText) findViewById(R.id.et_nickname);

        initwebView();

        webviewContainer = (FrameLayout) findViewById(R.id.webview_container);
        FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(FrameLayout.LayoutParams.MATCH_PARENT, FrameLayout.LayoutParams.MATCH_PARENT);
        webviewContainer.addView(mWebView, layoutParams);
    }

    void initwebView() {

        WebViewClient myWebClient = new WebViewClient() {

            @Override
            public void onPageFinished(WebView view, String url) {
                String result = "";

                super.onPageFinished(view, url);
            }
        };


        if (mWebView == null) {
            mWebView = new WebView(this);
        }
        else {
            mWebView.loadUrl("about:blank");
        }



        WebSettings settings = mWebView.getSettings();
        settings.setJavaScriptEnabled(true);
        settings.setCacheMode(WebSettings.LOAD_DEFAULT);        //缓存
        settings.setDomStorageEnabled(true);
        settings.setDatabaseEnabled(true);
        settings.setAppCacheEnabled(true);
        settings.setAllowFileAccess(true);
        settings.setTextZoom(100);

        mWebView.setWebViewClient(myWebClient);
        Locale locale = Locale.getDefault();
        String language = locale.getLanguage();
        if (!language.endsWith("zh")) {
            mWebView.setVisibility(View.GONE);
        }

//        final String url = "http://debugtbs.qq.com?" + String.valueOf(System.currentTimeMillis());
//        mWebView.loadUrl(url);
    }

    @Override
    public void onTIMForceOffline() {
        super.onTIMForceOffline();
        finish();
    }

    @Override
    public void onTIMUserSigExpired() {
        super.onTIMUserSigExpired();
        finish();
    }

    @Override
    protected void onStop() {
        super.onStop();
        writeToCache(mRoomId);
    }

    public void writeToCache(int roomId) {
        SharedPreferences sharedPreferences = getSharedPreferences(TAG, 0);
        SharedPreferences.Editor editor = sharedPreferences.edit();
        editor.putInt(USER_ROOM, roomId);
        editor.commit();
    }

    public int resumeFromCache() {
        Random ran = new Random(System.currentTimeMillis());
        int randRoom = ran.nextInt(1000); //课堂号假设小于1000
        SharedPreferences sharedPreferences = getSharedPreferences(TAG, 0);
        int roomId = sharedPreferences.getInt(USER_ROOM, randRoom);
        return roomId;
    }

    /**
     * 退出
     */
    public void onExit(View v) {
        finish();
    }

    /**
     * 创建课堂
     */
    public void onCreateClsssroomClick(View v) {

        String inputString = etRoomIdInput.getText().toString().trim();
        if (TextUtils.isEmpty(inputString) || !TextUtils.isDigitsOnly(inputString)) {
            postToast(TextUtil.getString(R.string.create_classroom_failed_empty)  + inputString, true);
            return;
        }
        String groupId = etImGroupIDInput.getText().toString().trim();
        if (TextUtils.isEmpty(groupId)) {
            groupId = inputString;
        }
        mGroupID = groupId;

        mRoomId = Integer.valueOf(inputString);

        IMManager.getInstance().createIMGroup(groupId, new IMManager.IMCallBack() {
            @Override
            public void onComplete(int errCode, String errMsg) {
                if (errCode == 0) {
                    postToast(TextUtil.getString(R.string.create_classroom_success)  + mGroupID, true);
                }
                else if (errCode == 10021) {
                    postToast(TextUtil.getString(R.string.classroom_already_created_by_others), true);
                }
                else if (errCode == 10025) {
                    postToast(TextUtil.getString(R.string.classroom_already_created), true);
                }
                else {
                    postToast(TextUtil.getString(R.string.create_classroom_failed) + mGroupID + " err:" + errCode + " msg:" + errMsg, true);
                }
            }
        });
    }

    public void onDestroyClassroomClick(View v) {

        String roomInputId = etRoomIdInput.getText().toString().trim();
        if (TextUtils.isEmpty(roomInputId) || !TextUtils.isDigitsOnly(roomInputId)) {
            postToast(TextUtil.getString(R.string.please_check_account_info));
            return;
        }
        String groupId = etImGroupIDInput.getText().toString().trim();
        if (TextUtils.isEmpty(groupId)) {
            groupId = roomInputId;
        }
        mGroupID = groupId;
        mRoomId = Integer.valueOf(roomInputId);

        IMManager.getInstance().destroyIMGroup(mGroupID, new IMManager.IMCallBack() {
            @Override
            public void onComplete(int errCode, String errMsg) {
                if (errCode == 0) {
                    postToast(TextUtil.getString(R.string.destroy_classroom_success) + mGroupID);
                }
                else {
                    postToast(TextUtil.getString(R.string.destroy_classroom_failed) + mGroupID + " err:" + errCode + " msg:" + errMsg);
                }
            }
        });
    }

    /**
     * 进入课堂
     */
    public void onJoinClsssroomClick(View v) {

        String roomInputId = etRoomIdInput.getText().toString().trim();
        if (TextUtils.isEmpty(roomInputId) || !TextUtils.isDigitsOnly(roomInputId)) {
            postToast(TextUtil.getString(R.string.create_classroom_failed_empty)  + roomInputId, true);
            return;
        }
        String groupId = etImGroupIDInput.getText().toString().trim();
        if (TextUtils.isEmpty(groupId)) {
            groupId = roomInputId;
        }
        mGroupID = groupId;

        mRoomId = Integer.valueOf(roomInputId);
        mNickName = etNickNameInput.getText().toString().trim();
        launcherClassroomLiveActivity();

        postToast(TextUtil.getString(R.string.entering_classroom), true);
    }

    private void launcherClassroomLiveActivity() {
        Intent intent = new Intent(this, TICClassMainActivity.class);
        intent.putExtra(USER_ID, mUserID);
        intent.putExtra(USER_SIG, mUserSig);
        intent.putExtra(USER_ROOM, mRoomId);
        intent.putExtra(USER_IM_GROUP, mGroupID);
        intent.putExtra(USER_NICKNAME, mNickName);
        startActivity(intent);
    }
}
