package com.tencent.tic.demo.activities;

import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.TextView;

import com.tencent.imsdk.v2.V2TIMManager;
import com.tencent.teduboard.TEduBoardController;
import com.tencent.teduboard.TEduBoardResourceController;
import com.tencent.tic.core.*;
import com.tencent.tic.demo.R;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.ProtocolException;
import java.net.URL;

public class TICLoginActivity extends BaseActvity implements CompoundButton.OnCheckedChangeListener {
    public EditText courseTextView;
    public Button courseBtn;
    public String courseUrl;
    public EditText customTextView;
    public Button customBtn;
    public String customUrl;
    private Object listener;
    private EditText userIdEditText;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_login_layout);
        tvLog = (TextView) findViewById(R.id.tv_login_log);
        userIdEditText = findViewById(R.id.et_user_id);

        mUserID = "tiw_android_user_" + Math.round(Math.random() * 10000);
        userIdEditText.setText(mUserID);
        userIdEditText.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence charSequence, int i, int i1, int i2) {

            }

            @Override
            public void onTextChanged(CharSequence charSequence, int i, int i1, int i2) {
                mUserID = charSequence.toString();
            }

            @Override
            public void afterTextChanged(Editable editable) {

            }
        });

        courseTextView = (EditText)findViewById(R.id.courseTextView);
        courseBtn = (Button)findViewById(R.id.courseButton);
        courseBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                preloadCourse();
            }
        });

        customTextView = (EditText)findViewById(R.id.customTextView);
        customBtn = (Button)findViewById(R.id.customButton);
        customBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                preloadCustom();
            }
        });

        TextView imVersionTV = (TextView) findViewById(R.id.tv_version_im);
        imVersionTV.setText("IMSDK: " + V2TIMManager.getInstance().getVersion());
        TextView boardVersionTV = (TextView) findViewById(R.id.tv_version_board);
        boardVersionTV.setText("TEduBoard: " + TEduBoardController.getVersion());
        setConfig(sdkAppId, mUserID);
    }

    @Override
    protected void onStop() {
        super.onStop();
        if (isFinishing()) {
            onLogoutClick(null);
        }
    }

    /**
     * 登录
     */
    public void onLoginClick(View v) {
        // 默认走的是云上环境
        if (TextUtils.isEmpty(mUserID)) {
            postToast(TextUtil.getString(R.string.please_check_account_info));
            return;
        }
        writeToCache(mUserID);
        new Thread(new Runnable() {
            @Override
            public void run() {
                mUserSig = TICLoginActivity.getUserSig(mUserID);
                if (mUserSig == null || "".equals(mUserSig)) {
                    postToast(TextUtil.getString(R.string.get_user_sig_failed));
                    return;
                }
                IMManager.getInstance().login(mUserID, mUserSig, new IMManager.IMCallBack() {
                    @Override
                    public void onComplete(int errCode, String errMsg) {
                        if (errCode == 0) {
                            postToast(mUserID + TextUtil.getString(R.string.login_success), true);
                            launchClassManagerActivity();
                        }
                        else {
                            postToast(mUserID + TextUtil.getString(R.string.login_failed) + errCode + "  msg: " + errMsg);
                        }
                    }
                });
            }
        }).start();

    }

    static String getUserSig(String userId) {
        return "请填写正确的UserSig";
    }

    public void writeToCache(String userId) {
        SharedPreferences sharedPreferences = getSharedPreferences(TAG, 0);
        SharedPreferences.Editor editor = sharedPreferences.edit();
        editor.putString(USER_ID, userId);
        editor.commit();
    }

    public String resumeFromCache() {
        SharedPreferences sharedPreferences = getSharedPreferences(TAG, 0);
        String userId = sharedPreferences.getString(USER_ID, "");
        return userId;
    }

    public void onLogoutClick(View v) {
        IMManager.getInstance().logout(new IMManager.IMCallBack() {
            @Override
            public void onComplete(int errCode, String errMsg) {
                if (errCode == 0) {
                    postToast(mUserID + TextUtil.getString(R.string.logout_success), true);
                }
                else  {
                    postToast("登出失败, err:" + errCode + " msg: " + errMsg);
                }
            }
        });
    }

    @Override
    public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
    }

    private void launchClassManagerActivity() {
        Intent intent = new Intent(this, TICClassManagerActivity.class);
        intent.addFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP);
        intent.putExtra(TICClassManagerActivity.USER_ID, mUserID);
        intent.putExtra(TICClassManagerActivity.USER_SIG, mUserSig);
        startActivity(intent);
    }

    /**
     * 课前预加载课件
     *
     * @param sdkAppId
     * @param userId
     */
    private void setConfig(final int sdkAppId, final String userId) {
        listener = new TEduBoardResourceController.TEduBoardResourceListener() {

            @Override
            public void onTIWCacheUpdateResourceCompleted(int force) {
                Log.d("TIWCacheListener", "资源更新 ： " + force);
            }

            @Override
            public void onTIWCacheCoursewareDownloaded(String zipUrl, int errcode, String message) {
                Log.d("TIWCacheListener", "课件下载 ： " + zipUrl + " : " + errcode);
            }

            @Override
            public void onTIWCacheFileDownloaded(String fileUrl, int errcode, String message) {

            }

            @Override
            public void onTIWCacheDownloading(String zipUrl, int progress, String errMessage) {
                if (zipUrl.equals(courseUrl)) {
                    courseBtn.setText(TextUtil.getString(R.string.courseware_preloading) + progress + "%");
                    if (progress >= 100) {
                        courseBtn.setClickable(true);
                    }
                }
                if (zipUrl.equals(customUrl)) {
                    customBtn.setText(TextUtil.getString(R.string.custom_preloading) + progress + "%");
                    if (progress >= 100) {
                        customBtn.setClickable(true);
                    }
                }
                Log.d("TIWCacheListener",  zipUrl + TextUtil.getString(R.string.download_progress) + progress + "%, errMessage: " + errMessage);
            }
        };
        TEduBoardResourceController.getInstance().addTEduBoardResourceListener( (TEduBoardResourceController.TEduBoardResourceListener)listener);
        final Context ctx = this;
        TEduBoardResourceController.getInstance().setConfig(ctx, sdkAppId, userId);
//        TEduBoardResourceController.getInstance().loadResource(this, "https://test-1259648581.cos.ap-shanghai.myqcloud.com/ppt/0u4mljum5cctsl2mr27c_tiw/0u4mljum5cctsl2mr27c.zip", -1);
//        TEduBoardResourceController.getInstance().preloadFile(this, "https://res.qcloudtiw.com/demo/tiw-vod.mp4", -1);
    }

    private void preloadCourse() {
        String url = courseTextView.getText().toString().trim();
        if (TextUtils.isEmpty(url) ) {
            postToast(TextUtil.getString(R.string.courseware_url_empty), true);
            return;
        }
        if (!url.toLowerCase().startsWith("http")) {
            postToast(TextUtil.getString(R.string.courseware_url_http_https), true);
            return;
        }
        TEduBoardResourceController.getInstance().loadResource(this, url, -1);
        courseBtn.setClickable(false);
        courseUrl = url;
    }

    private void preloadCustom() {
        String url = customTextView.getText().toString().trim();
        if (TextUtils.isEmpty(url) ) {
            postToast(TextUtil.getString(R.string.custom_resource_url_empty), true);
            return;
        }
        if (!url.toLowerCase().startsWith("http")) {
            postToast(TextUtil.getString(R.string.custom_resource_url_http_https), true);
            return;
        }
        TEduBoardResourceController.getInstance().preloadFile(this, url, -1);
        customBtn.setClickable(false);
        customUrl = url;
    }
}
