package com.tencent.tic.demo.activities;

import android.app.Dialog;
import android.content.Context;
import android.graphics.Color;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.MimeTypeMap;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.SeekBar;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import androidx.appcompat.app.AppCompatActivity;
import androidx.fragment.app.DialogFragment;

import com.tencent.teduboard.TEduBoardController;
import com.tencent.tic.core.TextUtil;
import com.tencent.tic.demo.R;

import java.io.IOException;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import top.defaults.colorpicker.ColorPickerPopup;


public class TICMenuDialog extends Dialog implements View.OnClickListener {

    private final static String TAG = "TICMenuDialog";
    final static String LOCAL_FILE = "local:";
    private boolean isNextTextFocusable;
    private WeakReference<AppCompatActivity> activity = null;

    public void setCurrentActivity(AppCompatActivity activity) {
        this.activity = new WeakReference<AppCompatActivity>(activity);;
    }
    //涂鸭工具集映射
    static class ToolType {
        ToolType(String name, int type) {
            this.name = name;
            this.type = type;
        }

        String name;
        int type;
    }

    static class KValue {
        KValue(String key, String value) {
            this.key = key;
            this.value = value;
        }

        String key;
        String value;
    }

    private final static String[] Images_URL = {
            "https://main.qcloudimg.com/raw/f221068a0de6040c42d73344a72c387b.jpg",
            "https://main.qcloudimg.com/raw/406551d15f1792b65d6586756b445c92.jpg",
            "https://main.qcloudimg.com/raw/372a34196487aac1cb65b542a6633af5.jpg",
            "https://main.qcloudimg.com/raw/ee75b1d4fa855cba8072839ed924ab86.jpg",
            "https://main.qcloudimg.com/raw/ee67a580472142bd618a8e42ce62a28b.jpg",
            "https://main.qcloudimg.com/raw/692c1da42fc56c62da866516b33e05f1.jpg",
            "https://main.qcloudimg.com/raw/4da1910077d346d8aa62b2b27c11459a.jpg",
            "https://main.qcloudimg.com/raw/a3a3eda87602bd3a346261a9be95b78d.jpg",
            "https://main.qcloudimg.com/raw/9cea6ec724ac3ca034a0424ec0afe8f5.jpg",
            "https://main.qcloudimg.com/raw/0e8988b172633f3381a9135494207f3a.jpg",
            "https://main.qcloudimg.com/raw/e8798f7bd522ab3ffe0a43d8b9d346cd.jpg"
    };

    //PPT转码后的H5文件，
    private final static TEduBoardController.TEduBoardTranscodeFileResult H5_PPT_URL[] = {
            new TEduBoardController.TEduBoardTranscodeFileResult(TextUtil.getString(R.string.welcome_new_student), "https://test-1259648581.file.myqcloud.com/ppt/0dfmongov3gvpfs3mr5c/index.html", 23, "960x540"),
            //    new TEduBoardController.TEduBoardTranscodeFileResult(TextUtil.getString(R.string.cos_transcoding), "https://testci-1257307760.cos.ap-guangzhou.myqcloud.com/%E6%AC%A2%E8%BF%8E%E6%96%B0%E5%90%8C%E5%AD%A6%20-%20%E5%BA%8F%E5%8F%B7.ppt?for_tiw=1"),
            new TEduBoardController.TEduBoardTranscodeFileResult(TextUtil.getString(R.string.pdf_title), "https://test-1259648581.file.myqcloud.com/ppt/0001nngov3gvpvfe9p5c/", 137, "959x539")
    };

    //H5背景
    private final static KValue[] H5_BK_URL = {
            new KValue("https://cloud.tencent.com/product/tiw", TextUtil.getString(R.string.whiteboard)),
            new KValue("https://cloud.tencent.com/solution/tic", TextUtil.getString(R.string.online_classroom)),
    };

    //H5 background
    private final static KValue[] BACKGROUND_IMAGE = {
            new KValue("https://demo-1259648581.cos.ap-nanjing.myqcloud.com/image/3e1ac1a1929b7561a9299c544cffae12.jpeg", "jpg1"),
            new KValue("https://demo-1259648581.cos.ap-nanjing.myqcloud.com/image/9a2da4ee6a631ce06ca6177a250a6fc5.jpg", "jpg2"),
            new KValue("https://demo-1259648581.cos.ap-nanjing.myqcloud.com/image/13256d24640f79202c90950cf5e653c6.jpeg", "jpg3"),
            new KValue("https://demo-1259648581.cos.ap-nanjing.myqcloud.com/image/3d2978eb75aaed3a85ea693bd63349a4.jpeg", "jpg4"),
    };

    //H5 file
    private final static KValue[] H5_FILE_URL = {
            new KValue("https://cloud.tencent.com/", TextUtil.getString(R.string.tencent_cloud)),
    };

    //Video
    private final static KValue[] VideoRes_URL = {
            new KValue("https://tic-res-1259648581.cos.ap-shanghai.myqcloud.com/demo/tiw-vod.mp4", TextUtil.getString(R.string.tencent_education))
    };

    //Video
    private final static KValue[] AudioRes_URL = {
            new KValue("https://test-1259648581.cos.ap-shanghai.myqcloud.com/media/xxx.mp3", TextUtil.getString(R.string.audio_1)),
            new KValue("https://test-1259648581.cos.ap-shanghai.myqcloud.com/%E6%A2%81%E9%9D%99%E8%8C%B9%20-%20%E6%83%85%E6%AD%8C.mp3", TextUtil.getString(R.string.audio_2))
    };
    //白板元素
    private final static KValue[] ELEMENT_URL = {
            new KValue(TextUtil.getString(R.string.image), "https://main.qcloudimg.com/raw/be5d8bc407204d0e1dea30bacd6d006b.png"),
            new KValue("h5", "https://www.qq.com"),
            new KValue(TextUtil.getString(R.string.custom_shape), "https://test-1259648581.cos.ap-shanghai.myqcloud.com/%E4%B8%89%E8%A7%92%E5%BD%A2.svg"),
            new KValue(TextUtil.getString(R.string.audio), "https://eric-test-1259648581.cos.ap-guangzhou.myqcloud.com/test.mp3")
    };

    final ToolType[] mToolMap = {
            new ToolType(TextUtil.getString(R.string.mouse), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_MOUSE),
            new ToolType(TextUtil.getString(R.string.pencil), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_PEN),
            new ToolType(TextUtil.getString(R.string.eraser), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_ERASER),
            new ToolType(TextUtil.getString(R.string.line), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_LINE),
            new ToolType(TextUtil.getString(R.string.laser_pointer), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_LASER),
            new ToolType(TextUtil.getString(R.string.hollow_ellipse), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_OVAL),
            new ToolType(TextUtil.getString(R.string.hollow_rectangle), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_RECT),
            new ToolType(TextUtil.getString(R.string.solid_ellipse), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_OVAL_SOLID),
            new ToolType(TextUtil.getString(R.string.solid_rectangle), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_RECT_SOLID),
            new ToolType(TextUtil.getString(R.string.click_to_select), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_POINT_SELECT),
//            new ToolType(TextUtil.getString(R.string.select), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_RECT_SELECT),
            new ToolType(TextUtil.getString(R.string.text), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_TEXT),
            new ToolType(TextUtil.getString(R.string.gesture_zoom), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_ZOOM_DRAG),
            new ToolType(TextUtil.getString(R.string.hollow_square), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_SQUARE),
            new ToolType(TextUtil.getString(R.string.solid_square), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_SQUARE_SOLID),
            new ToolType(TextUtil.getString(R.string.hollow_circle), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_CIRCLE),
            new ToolType(TextUtil.getString(R.string.solid_circle), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_CIRCLE_SOLID),
            new ToolType(TextUtil.getString(R.string.custom_shape), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_BOARD_CUSTOM_GRAPH),
//            new ToolType(TextUtil.getString(R.string.arc), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_ARC),
            new ToolType(TextUtil.getString(R.string.highlighter), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_HIGHLIGHTER),
            new ToolType(TextUtil.getString(R.string.right_triangle), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_RIGHT_TRIANGLE),
            new ToolType(TextUtil.getString(R.string.isosceles_triangle), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_ISOSCELES_TRIANGLE),
            new ToolType(TextUtil.getString(R.string.parallelogram), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_PARALLELOGRAM),
            new ToolType(TextUtil.getString(R.string.cube), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_CUBE),
            new ToolType(TextUtil.getString(R.string.cylinder), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_CYLINDER),
            new ToolType(TextUtil.getString(R.string.cone), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_CONE),
            new ToolType(TextUtil.getString(R.string.coordinate_system), TEduBoardController.TEduBoardToolType.TEDU_BOARD_TOOL_TYPE_COORDINATE)
    };

    final ToolType[] mGraphStyle = {
            new ToolType(TextUtil.getString(R.string.dashed_line_no_arrow), 0),
            new ToolType(TextUtil.getString(R.string.solid_line_arrow_end), 1),
            new ToolType(TextUtil.getString(R.string.dashed_line_start_arrow), 2),
            new ToolType(TextUtil.getString(R.string.solid_line_arrow_start_end), 3),
            new ToolType(TextUtil.getString(R.string.solid_triangle), 4),
            new ToolType(TextUtil.getString(R.string.dashed_hollow_rectangle), 5),
            new ToolType(TextUtil.getString(R.string.solid_isosceles_triangle), 6),
            new ToolType(TextUtil.getString(R.string.solid_right_triangle), 7),
            new ToolType(TextUtil.getString(R.string.solid_parallelogram), 8),
    };

    final ToolType[] mMagicPenType = {
            new ToolType(TextUtil.getString(R.string.not_fit), 0),
            new ToolType(TextUtil.getString(R.string.fit_on_lift), 1),
            new ToolType(TextUtil.getString(R.string.fit_after_long_press), 2),
    };

    final ToolType[] mMathToolMap = {
            new ToolType(TextUtil.getString(R.string.ruler), TEduBoardController.TEduMathToolType.RULER),
            new ToolType(TextUtil.getString(R.string.right_triangle), TEduBoardController.TEduMathToolType.TRIANGLE),
            new ToolType(TextUtil.getString(R.string.isosceles_right_triangle), TEduBoardController.TEduMathToolType.ISOSCELES_TRIANGLE),
            new ToolType(TextUtil.getString(R.string.protractor), TEduBoardController.TEduMathToolType.PROTRACTOR),
            new ToolType(TextUtil.getString(R.string.compass), TEduBoardController.TEduMathToolType.COMPASSES),
    };


    final ToolType[] TextStyle = {
            new ToolType(TextUtil.getString(R.string.general), TEduBoardController.TEduBoardTextStyle.TEDU_BOARD_TEXT_STYLE_NORMAL),
            new ToolType(TextUtil.getString(R.string.bold), TEduBoardController.TEduBoardTextStyle.TEDU_BOARD_TEXT_STYLE_BOLD),
            new ToolType(TextUtil.getString(R.string.italic), TEduBoardController.TEduBoardTextStyle.TEDU_BOARD_TEXT_STYLE_ITALIC),
            new ToolType(TextUtil.getString(R.string.bold_italic), TEduBoardController.TEduBoardTextStyle.TEDU_BOARD_TEXT_STYLE_BOLD_ITALIC),
    };

    final ToolType[] FitMode = {
            new ToolType(TextUtil.getString(R.string.default_mode), TEduBoardController.TEduBoardContentFitMode.TEDU_BOARD_CONTENT_FIT_MODE_NONE),
            new ToolType(TextUtil.getString(R.string.fill_whiteboard), TEduBoardController.TEduBoardContentFitMode.TEDU_BOARD_CONTENT_FIT_MODE_CENTER_INSIDE),
            new ToolType(TextUtil.getString(R.string.fill_container), TEduBoardController.TEduBoardContentFitMode.TEDU_BOARD_CONTENT_FIT_MODE_CENTER_COVER),
    };

    final ToolType[] WipeStyle = {
            new ToolType("LINE", TEduBoardController.TEduBoardErasableElementType.LINE),
            new ToolType("GRAPH", TEduBoardController.TEduBoardErasableElementType.GRAPH),
            new ToolType("TEXT", TEduBoardController.TEduBoardErasableElementType.TEXT),
            new ToolType("IMAGE", TEduBoardController.TEduBoardErasableElementType.IMAGE),
            new ToolType("ELEMENT", TEduBoardController.TEduBoardErasableElementType.ELEMENT)
    };

    public interface IMoreListener {
        //TRTC
        void onEnableAudio(boolean bEnableAudio);

        void onSwitchAudioRoute(boolean speaker);

        void onEnableCamera(boolean bEnableCamera);

        void onSwitchCamera(boolean bFrontCamera);

        //Board(涂鸭操作)
        void onSetDrawEnable(boolean SetDrawEnable);

        void onSyncDrawEnable(boolean syncDrawEnable);

        void onMultiTouchEnable(boolean enableMultiTouch);

        void onTouchEnable(boolean enableMultiTouch);

        void onSegmentEraser(boolean segmentEraser);

        void onStartSnapshot();

        void onNextTextInput(String textContent, boolean keepFocus);

        void onAutoSelect(boolean autoSelect);

        void onTipTextInput(String textContent);

        void onWipeNumInput(int num);

        void onSetHandwritingEnable(boolean syncDrawEnable);

        void onSetSystemCursorEnable(boolean systemCursorEnable);

        void onSetToolType(int type);

        void onSetMagicPen(int type);

        void onSetGraphStyle(int type);

        void onSetMathToolType(int type);

        void onBrushThin(int size);

        void onSetTextSize(int size);

        void onSetEraserSize(int size);

        void onSetTextHeight(float height);

        void onScale(int scale);

        void onSetRatio(String scale);

        void onSetFitMode(int mode);

        void onAddElement(int type, String url);

        void onSetBrushColor(int color);

        void onSetTextColor(int color);

        void onSetHighlightColor(int color);

        void onSetTextStyle(int style);

        void onSetBackgroundColore(int color);

        void onSetGlobalBackgroundColore(int color);

        void onSetBackgroundImage(String path);

        void onSetBackgroundH5(String url);

        void setWipeType(int wipeType);

        void onSetNickNameVisiable(boolean visiable);

        void onUndo();

        void onRedo();

        void onClear();

        void onClearDraws();

        void onClearBackground();

        void onReset();

        void onSetPermission();

        //Board(白板操作)
        void onAddBoard(String url, int index);

        void onDeleteBoard(String boardId);

        void onGotoBoard(String boardId);

        void onPrevStep();

        void onNextStep();

        void onPrevBoard();

        void onNextBoard();


        //Board(文件操作)
        void onTransCodeFile(TEduBoardController.TEduBoardTranscodeFileResult result);

        void onAddH5File(String url);

        void onDeleteFile(String boardId);

        void onGotoFile(String boardId);

        void onAddImagesFile(List<String> urls);


        //Video()
        void onAddAudio(String url, String title);
        void onAddVideo();
        void onAddWatermark();

        void onExportInLocalMode();
        void onImportInLocalMode();

        void onExportInLocalModeWithFilter();
        void onImportInLocalModeWithFilter();

        void onHideElements();
        void onShowElements();

        void onShowVideoCtrl(boolean value);

        void onSyncAndReload();

        void onPlayAudio();

        void onPauseAudio();

        void onPlayPPPTVideo();

        void onPausePPPTVideo();

        void onPlayPPPTAudio();

        void onPausePPPTAudio();

        void onAddBackupDomain();

        void onRemoveBackupDomain();

        //分组操作  
        void onAddBoardToClassGroup(String groupId, String boardId);

        void onAddUserToClassGroup(String groupId,String userId);

        void onGetAllClassGroupIds();

        void onGetClassGroupEnable();

        void onGetClassGroupIdByUserId(String userId);

        void onGetClassGroupInfoByGroupId(String groupId);

        void onGotoClassGroupBoard(String boardId);

        void onRemoveBoardInClassGroup(String groupId,String boardId);

        void onRemoveClassGroup(String groupId);

        void onRemoveUserInClassGroup(String groupId,String userId);

        void onResetClassGroup();

        void onSetClassGroup(String groupId,List<String> boards,List<String> users,String title,String currentBoardId);

        void onSetClassGroupEnable(boolean enable);

        void onSetClassGroupTitle(String groupId,String title);

        void showToast(String toast);
    }

    //显示时的值
    public static class SettingCacheData {
        //trtc
        boolean AudioEnable;
        boolean AudioRoute;
        boolean CameraEnable;
        boolean CameraFront;

        //board(涂鸭)
        boolean isDrawEnable;       //是否可以涂鸭
        boolean isSynDrawEnable; //是否将你画的涂鸭同步给其他人
        boolean isMultiTouch; //是否将你画的涂鸭同步给其他人
        boolean isDisableTouch; //是否禁用触控
        boolean isSegmentEraser; //是否开启分段擦除
        boolean isNickNameVisiable = true;
        boolean isHandwritingEnable;
        boolean isAutoSelect;
        int ToolType;
        int magicPenType;
        int mathToolType;
        int graphStyle;
        int BrushThin;
        int BrushColor;
        int highlightColor;
        int TextColor;
        int TextStyle;
        String TextFamily;
        int BackgroundColor;
        int GlobalBackgroundColor;
        int TextSize;
        int TextHeight;
        int EraserSize;
        int ScaleSize;
        int FitMode;
        String ration;
        String BackgroundImage;
        boolean canRedo;
        boolean canUndo;

        //board(白板操作)
        String currentBoardId;
        List<String> boardIds;

        //board(文件操作)
        String currentFileId;
        List<TEduBoardController.TEduBoardFileInfo> files;
    }

    ;


    WeakReference<IMoreListener> mMoreListener;
    static SettingCacheData mSettingData;

    //
    ArrayAdapter<String> boardArray;

    public TICMenuDialog(Context context, IMoreListener listener) {
        super(context, R.style.room_more_dlg);
        mMoreListener = new WeakReference<>(listener);
        mSettingData = new SettingCacheData();

    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.dlg_setting);
        getWindow().setLayout(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT);

        //initView(mSettingData);
    }

    @Override
    protected void onStart() {
        initView(mSettingData);
        super.onStart();
    }

    public void show(SettingCacheData settingData) {
        mSettingData = settingData;
        show();
    }

    private void initView(SettingCacheData settingData) {
        //返回
        findViewById(R.id.btn_back).setOnClickListener(this);

        //---------Board(涂鸭)---------
        CheckBox board_nextTextFocusable = findViewById(R.id.board_setNextTextFocusable);
        board_nextTextFocusable.setOnClickListener(this);
        //   board_nextTextFocusable.setChecked(false);

        CheckBox board_autoSelect = findViewById(R.id.board_autoSelect);
        board_autoSelect.setOnClickListener(this);
        board_autoSelect.setChecked(settingData.isAutoSelect);

        CheckBox board_isDrawEnable = findViewById(R.id.board_setDrawEnable);
        board_isDrawEnable.setOnClickListener(this);
        board_isDrawEnable.setChecked(settingData.isDrawEnable);

        CheckBox board_isSycDrawEnable = findViewById(R.id.board_SynDrawEnable);
        board_isSycDrawEnable.setOnClickListener(this);
        board_isSycDrawEnable.setChecked(settingData.isSynDrawEnable);

        CheckBox board_multiTouch = findViewById(R.id.board_multiTouch);
        board_multiTouch.setOnClickListener(this);
        board_multiTouch.setChecked(settingData.isMultiTouch);

        CheckBox board_disableTouch = findViewById(R.id.board_disableTouch);
        board_disableTouch.setOnClickListener(this);
        board_disableTouch.setChecked(settingData.isDisableTouch);

        CheckBox board_segmentEraser = findViewById(R.id.board_segmentEraser);
        board_segmentEraser.setOnClickListener(this);
        board_segmentEraser.setChecked(settingData.isSegmentEraser);


        Button boardSnapshotBtn = (Button) findViewById(R.id.board_snapshot);
        boardSnapshotBtn.setOnClickListener(this);

        Button boardNextTextBtn = (Button) findViewById(R.id.board_nextText);
        boardNextTextBtn.setOnClickListener(this);

        Button boardTipTextBtn = (Button) findViewById(R.id.board_tipText);
        boardTipTextBtn.setOnClickListener(this);

        Button boardWipeTextBtn = (Button) findViewById(R.id.board_wipeText);
        boardWipeTextBtn.setOnClickListener(this);

        CheckBox HandwritingEnable = findViewById(R.id.board_setHandwritingEnable);
        HandwritingEnable.setOnClickListener(this);
        HandwritingEnable.setChecked(settingData.isHandwritingEnable);

        RadioButton mRbCursorEnable = (RadioButton) findViewById(R.id.cursor_yes);
        mRbCursorEnable.setOnClickListener(this);

        RadioButton mRbCursorNoEnable = (RadioButton) findViewById(R.id.cursor_no);
        mRbCursorNoEnable.setOnClickListener(this);

        int posMathToolType = 0;
        ArrayAdapter<String> mathAdapter = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (int i = 0; i < mMathToolMap.length; i++) {
            mathAdapter.add(mMathToolMap[i].name);
            if (settingData.mathToolType == mMathToolMap[i].type) {
                posMathToolType = i;
            }
        }
        Spinner spMathToolType = (Spinner) findViewById(R.id.sp_SetToolMathType);
        spMathToolType.setAdapter(mathAdapter);
        spMathToolType.setSelection(posMathToolType, false);
        findViewById(R.id.btn_SetMathToolType).setOnClickListener(this);

        int posToolType = 0;
        ArrayAdapter<String> adapter = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (int i = 0; i < mToolMap.length; i++) {
            adapter.add(mToolMap[i].name);
            if (settingData.ToolType == mToolMap[i].type) {
                posToolType = i;
            }
        }
        Spinner spToolType = (Spinner) findViewById(R.id.sp_SetToolType);
        spToolType.setAdapter(adapter);
        spToolType.setSelection(posToolType, false);
        findViewById(R.id.btn_SetToolType).setOnClickListener(this);

        int posGraphStyle = 0;
        ArrayAdapter<String> graphStyleAdapter = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (int i = 0; i < mGraphStyle.length; i++) {
            graphStyleAdapter.add(mGraphStyle[i].name);
            if (settingData.graphStyle == mGraphStyle[i].type) {
                posGraphStyle = i;
            }
        }
        Spinner spGraphStyle = (Spinner) findViewById(R.id.sp_SetGraphStyle);
        spGraphStyle.setAdapter(graphStyleAdapter);
        spGraphStyle.setSelection(posGraphStyle, false);
        findViewById(R.id.btn_SetGraphStyle).setOnClickListener(this);

        int magicPenType = 0;
        ArrayAdapter<String> magicPendapter = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (int i = 0; i < mMagicPenType.length; i++) {
            magicPendapter.add(mMagicPenType[i].name);
            if (settingData.magicPenType == mMagicPenType[i].type) {
                magicPenType = i;
            }
        }
        Spinner spMagicPenType = (Spinner) findViewById(R.id.sp_SetMagicPen);
        spMagicPenType.setAdapter(magicPendapter);
        spMagicPenType.setSelection(magicPenType, false);
        findViewById(R.id.btn_SetMagicPen).setOnClickListener(this);

        findViewById(R.id.btn_BrushThin).setOnClickListener(this);
        ((TextView) findViewById(R.id.tv_BrushThin)).setText(String.valueOf(settingData.BrushThin));
        SeekBar sbVideoBitrate = findViewById(R.id.sk_BrushThin);
        sbVideoBitrate.setProgress(settingData.BrushThin);
        sbVideoBitrate.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
            @Override
            public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
                ((TextView) findViewById(R.id.tv_BrushThin)).setText(String.valueOf(progress));
            }

            @Override
            public void onStartTrackingTouch(SeekBar seekBar) {
            }

            @Override
            public void onStopTrackingTouch(SeekBar seekBar) {
            }
        });

        findViewById(R.id.btn_SetTextSize).setOnClickListener(this);
        ((TextView) findViewById(R.id.tv_SetTextSize)).setText(String.valueOf(settingData.TextSize));
        SeekBar sk_TextSize = (SeekBar) findViewById(R.id.sk_SetTextSize);
        sk_TextSize.setProgress(settingData.TextSize);
        sk_TextSize.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
            @Override
            public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
                ((TextView) findViewById(R.id.tv_SetTextSize)).setText(String.valueOf(progress));
            }

            @Override
            public void onStartTrackingTouch(SeekBar seekBar) {
            }

            @Override
            public void onStopTrackingTouch(SeekBar seekBar) {
            }
        });

        // 字体行高
        findViewById(R.id.btn_SetTextHeight).setOnClickListener(this);
        ((TextView) findViewById(R.id.tv_SetTextHeight)).setText(String.valueOf(settingData.TextHeight));
        SeekBar sk_TextHeight = (SeekBar) findViewById(R.id.sk_SetTextHeight);
        sk_TextHeight.setProgress(settingData.TextHeight);
        sk_TextHeight.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
            @Override
            public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
                ((TextView) findViewById(R.id.tv_SetTextHeight)).setText(String.valueOf(progress));
            }

            @Override
            public void onStartTrackingTouch(SeekBar seekBar) {
            }

            @Override
            public void onStopTrackingTouch(SeekBar seekBar) {
            }
        });

        // 橡皮擦大小
        findViewById(R.id.btn_SetEraserSize).setOnClickListener(this);
        ((TextView) findViewById(R.id.tv_SetEraserSize)).setText(String.valueOf(settingData.EraserSize));
        SeekBar sk_SetEraserSize = (SeekBar) findViewById(R.id.sk_SetEraserSize);
        sk_SetEraserSize.setProgress(settingData.EraserSize);
        sk_SetEraserSize.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
            @Override
            public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
                ((TextView) findViewById(R.id.tv_SetEraserSize)).setText(String.valueOf(progress));
            }

            @Override
            public void onStartTrackingTouch(SeekBar seekBar) {
            }

            @Override
            public void onStopTrackingTouch(SeekBar seekBar) {
            }
        });

        //缩放
        findViewById(R.id.btn_scaleBoard).setOnClickListener(this);
        ((TextView) findViewById(R.id.tv_scaleBoard)).setText(String.valueOf(settingData.ScaleSize));
        SeekBar sk_scaleBoard = (SeekBar) findViewById(R.id.sk_scaleBoard);
        sk_scaleBoard.setProgress(settingData.ScaleSize);
        sk_scaleBoard.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
            @Override
            public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
                ((TextView) findViewById(R.id.tv_scaleBoard)).setText(String.valueOf(progress));
            }

            @Override
            public void onStartTrackingTouch(SeekBar seekBar) {
            }

            @Override
            public void onStopTrackingTouch(SeekBar seekBar) {
            }
        });

        //宽高比
        RadioButton mRbBoardRation169 = (RadioButton) findViewById(R.id.board_16_9);
        String ratio169 = mRbBoardRation169.getText().toString();
        mRbBoardRation169.setOnClickListener(this);
        mRbBoardRation169.setChecked(!TextUtils.isEmpty(ratio169) && ratio169.equals(settingData.ration));

        RadioButton mRbBoardRation43 = (RadioButton) findViewById(R.id.board_4_3);
        String ratio43 = mRbBoardRation43.getText().toString();
        mRbBoardRation43.setOnClickListener(this);
        mRbBoardRation43.setChecked(!TextUtils.isEmpty(ratio43) && ratio43.equals(settingData.ration));


        //填充模式
        int fitModeType = 0;
        ArrayAdapter<String> fitMode_adapter = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (int i = 0; i < FitMode.length; i++) {
            fitMode_adapter.add(FitMode[i].name);
            if (settingData.FitMode == FitMode[i].type) {
                fitModeType = i;
            }
        }
        Spinner spFitMode = (Spinner) findViewById(R.id.sp_fitMode);
        spFitMode.setAdapter(fitMode_adapter);
        spFitMode.setSelection(fitModeType, false);
        findViewById(R.id.btn_fitMode).setOnClickListener(this);

        //撤销和重做
        Button bt_undo = findViewById(R.id.btn_undo);
        bt_undo.setEnabled(settingData.canUndo);
        bt_undo.setOnClickListener(this);

        Button bt_redo = findViewById(R.id.btn_redo);
        bt_redo.setEnabled(settingData.canRedo);
        bt_redo.setOnClickListener(this);

        findViewById(R.id.btn_clear).setOnClickListener(this);
        findViewById(R.id.btn_clearDraws).setOnClickListener(this);
        findViewById(R.id.btn_clearBackground).setOnClickListener(this);
        findViewById(R.id.btn_reset).setOnClickListener(this);
        findViewById(R.id.btn_setPermission).setOnClickListener(this);

        ArrayAdapter<String> elements = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (int i = 0; i < ELEMENT_URL.length; i++) {
            elements.add(ELEMENT_URL[i].key);
        }
        Spinner spElementColor = (Spinner) findViewById(R.id.sp_addElement);
        spElementColor.setAdapter(elements);
        spElementColor.setSelection(0, false);
        findViewById(R.id.btn_addElement).setOnClickListener(this);

        int pos_textstyle = 0;
        ArrayAdapter<String> textstyle = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (int i = 0; i < TextStyle.length; i++) {
            textstyle.add(TextStyle[i].name);
            if (TextStyle[i].type == settingData.TextStyle) {
                pos_textstyle = i;
            }
        }

        Spinner spTextStyle = (Spinner) findViewById(R.id.sp_setTextStyle);
        spTextStyle.setAdapter(textstyle);
        spTextStyle.setSelection(pos_textstyle, false);
        findViewById(R.id.btn_setTextStyle).setOnClickListener(this);
        {
            Button btn = findViewById(R.id.btn_selectBrushColor);
            setBtnColor(btn, mSettingData.BrushColor);
            btn.setOnClickListener(this);
            findViewById(R.id.btn_setBrushColor).setOnClickListener(this);
        }
        {
            Button btn = findViewById(R.id.btn_selectHighlightColor);
            setBtnColor(btn, mSettingData.highlightColor);
            btn.setOnClickListener(this);
            findViewById(R.id.btn_setHighlightColor).setOnClickListener(this);
        }

        {
            Button btn = findViewById(R.id.btn_selectTextColor);
            setBtnColor(btn, mSettingData.TextColor);
            btn.setOnClickListener(this);
            findViewById(R.id.btn_setTextColor).setOnClickListener(this);
        }
        {
            Button btn = findViewById(R.id.btn_selectBackgroundColor);
            setBtnColor(btn, mSettingData.BackgroundColor);
            btn.setOnClickListener(this);
            findViewById(R.id.btn_setBackgroundColor).setOnClickListener(this);
        }
        {
            Button btn = findViewById(R.id.btn_selectGlobalBackgroundColor);
            setBtnColor(btn, mSettingData.GlobalBackgroundColor);
            btn.setOnClickListener(this);
            findViewById(R.id.btn_setGlobalBackgroundColor).setOnClickListener(this);
        }



        ArrayAdapter<String> imgArray = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (int i = 0; i < BACKGROUND_IMAGE.length; i++) {
            imgArray.add(BACKGROUND_IMAGE[i].value);
        }
        Spinner backimage = (Spinner) findViewById(R.id.sp_setBackgroundImage);
        backimage.setAdapter(imgArray);
        backimage.setSelection(0, false);
        findViewById(R.id.btn_setBackgroundImage).setOnClickListener(this);


        ArrayAdapter<String> bgh5Array = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (int i = 0; i < H5_BK_URL.length; i++) {
            bgh5Array.add(H5_BK_URL[i].value);
        }
        Spinner bgh5 = (Spinner) findViewById(R.id.sp_setBackgroundH5);
        bgh5.setAdapter(bgh5Array);
        bgh5.setSelection(0, false);
        findViewById(R.id.btn_setBackgroundH5).setOnClickListener(this);


        ArrayAdapter<String> wipeTypeArray = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (int i = 0; i < WipeStyle.length; i++) {
            wipeTypeArray.add(WipeStyle[i].name);
        }
        Spinner wipeSp = (Spinner) findViewById(R.id.sp_set_wipe_type);
        wipeSp.setAdapter(wipeTypeArray);
        wipeSp.setSelection(0, false);
        findViewById(R.id.btn_set_wipe_type).setOnClickListener(this);

        CheckBox board_isNickNameVisiable = findViewById(R.id.board_setNickNameVisiable);
        board_isNickNameVisiable.setOnClickListener(this);
        board_isNickNameVisiable.setChecked(settingData.isNickNameVisiable);

        //---------Board(白板)---------
        findViewById(R.id.btn_prevBoard).setOnClickListener(this);
        findViewById(R.id.btn_nextBoard).setOnClickListener(this);

        findViewById(R.id.btn_prevStep).setOnClickListener(this);
        findViewById(R.id.btn_nextStep).setOnClickListener(this);


        findViewById(R.id.btn_addBoard).setOnClickListener(this);
        findViewById(R.id.btn_deleteBoard).setOnClickListener(this);
        findViewById(R.id.btn_gotoBoard).setOnClickListener(this);

        findViewById(R.id.board_audio_play).setOnClickListener(this);
        findViewById(R.id.board_audio_pause).setOnClickListener(this);

        int pos = 0;
        boardArray = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        if (settingData.boardIds != null && settingData.boardIds.size() > 0) {
            if (!TextUtils.isEmpty(mSettingData.currentBoardId)) {
                pos = settingData.boardIds.indexOf(mSettingData.currentBoardId);
            }

            boardArray.addAll(settingData.boardIds);
        }
        Spinner deleteboard = (Spinner) findViewById(R.id.sp_deleteBoard);
        deleteboard.setAdapter(boardArray);
        deleteboard.setSelection(pos >= 0 ? pos : 0, false);

        Spinner gotoboard = (Spinner) findViewById(R.id.sp_gotoBoard);
        gotoboard.setAdapter(boardArray);
        gotoboard.setSelection(pos >= 0 ? pos : 0, false);


        //---------Board(文件)---------
        findViewById(R.id.btn_addFile).setOnClickListener(this);
        findViewById(R.id.btn_deleteFile).setOnClickListener(this);
        findViewById(R.id.btn_switchFile).setOnClickListener(this);
        findViewById(R.id.btn_addImagesFile).setOnClickListener(this);
        findViewById(R.id.btn_addH5File).setOnClickListener(this);

        ArrayAdapter<String> pptArray = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (TEduBoardController.TEduBoardTranscodeFileResult file : H5_PPT_URL) {
            pptArray.add(file.title);
        }
//        Spinner sp_addFile = (Spinner) findViewById(R.id.sp_addFile);
//        sp_addFile.setAdapter(pptArray);

        int pos_file = 0;
        ArrayAdapter<String> filesArray = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        if (settingData.files != null) {
            int i = 0;
            for (TEduBoardController.TEduBoardFileInfo info : settingData.files) {
                filesArray.add(TextUtils.isEmpty(info.title) ? info.fileId : info.title);
                if (info.fileId.equals(mSettingData.currentFileId)) {
                    pos_file = i;
                }
                i++;
            }
        }

//        //H5文件
//        ArrayAdapter<String> H5FileArray = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
//        for (int i = 0; i < H5_FILE_URL.length; i++) {
//            H5FileArray.add(H5_FILE_URL[i].value);
//        }
//        Spinner H5FileSp = (Spinner) findViewById(R.id.sp_addH5File);
//        H5FileSp.setAdapter(H5FileArray);
//        H5FileSp.setSelection(0, false);


        Spinner deletefile = (Spinner) findViewById(R.id.sp_deleteFile);
        deletefile.setAdapter(filesArray);
        deletefile.setSelection(pos_file >= 0 ? pos_file : 0, false);

        Spinner switchfile = (Spinner) findViewById(R.id.sp_switchFile);
        switchfile.setAdapter(filesArray);
        switchfile.setSelection(pos_file >= 0 ? pos_file : 0, false);


        //---------数据导入导出---------
        findViewById(R.id.btn_exportInLocalMode).setOnClickListener(this);
        findViewById(R.id.btn_importInLocalMode).setOnClickListener(this);

        //---------过滤数据导入导出---------
        findViewById(R.id.btn_exportInLocalModeWithFilter).setOnClickListener(this);
        findViewById(R.id.btn_importInLocalModeWithFilter).setOnClickListener(this);

        //---------元素显示和隐藏---------
        findViewById(R.id.btn_hideElements).setOnClickListener(this);
        findViewById(R.id.btn_showElements).setOnClickListener(this);

        //---------视频(video)---------
        findViewById(R.id.btn_addVideoFile).setOnClickListener(this);
        findViewById(R.id.btn_video_ctrl_enalbe).setOnClickListener(this);

        findViewById(R.id.btn_playPPTVideo).setOnClickListener(this);
        findViewById(R.id.btn_playPPTAudio).setOnClickListener(this);
        findViewById(R.id.btn_pausePPTVideo).setOnClickListener(this);
        findViewById(R.id.btn_pausePPTAudio).setOnClickListener(this);

        // 添加水印
        findViewById(R.id.btn_addWatermark).setOnClickListener(this);

        findViewById(R.id.btn_addAudio).setOnClickListener(this);
        ArrayAdapter<String> audioArray = new ArrayAdapter<String>(this.getContext(), android.R.layout.simple_spinner_item, android.R.id.text1);
        for (int i = 0; i < AudioRes_URL.length; i++) {
            audioArray.add(AudioRes_URL[i].value);
        }
        Spinner audioSp = (Spinner) findViewById(R.id.sp_addAudio);
        audioSp.setAdapter(audioArray);
        audioSp.setSelection(0, false);

        findViewById(R.id.btn_reload).setOnClickListener(this);

        findViewById(R.id.btn_add_domain).setOnClickListener(this);

        findViewById(R.id.btn_remove_domain).setOnClickListener(this);


        findViewById(R.id.btn_addtoclassgroup).setOnClickListener(this);

        findViewById(R.id.btn_addusertoclassgroup).setOnClickListener(this);

        findViewById(R.id.btn_getallclassgroupids).setOnClickListener(this);

        findViewById(R.id.btn_getclassgroupenable).setOnClickListener(this);

        findViewById(R.id.btn_getclassgroupbyuserid).setOnClickListener(this);

        findViewById(R.id.btn_getClassGroupInfoByGroupId).setOnClickListener(this);

        findViewById(R.id.btn_gotoClassGroupBoard).setOnClickListener(this);

        findViewById(R.id.btn_removeBoardInClassGroup).setOnClickListener(this);

        findViewById(R.id.btn_removeClassGroup).setOnClickListener(this);

        findViewById(R.id.btn_removeUserInClassGroup).setOnClickListener(this);

        findViewById(R.id.btn_resetClassGroup).setOnClickListener(this);

        findViewById(R.id.btn_setClassGroup).setOnClickListener(this);

        findViewById(R.id.btn_setClassGroupEnable).setOnClickListener(this);

        findViewById(R.id.btn_setClassGroupTitle).setOnClickListener(this);

    }
    public void updateCanUndo(boolean canundo) {
        Button bt_undo = findViewById(R.id.btn_undo);
        bt_undo.setEnabled(canundo);
    }

    public void updateCanRedo(boolean canredo) {
        Button bt_redo = findViewById(R.id.btn_redo);
        bt_redo.setEnabled(canredo);
    }
    void setBtnColor(Button btn, int color) {
        String colorText = Integer.toHexString(color).toUpperCase();
        String title = TextUtil.getString(R.string.color) + colorText + " ▼";
        btn.setText(title);
        btn.setTextColor(Color.WHITE);
    }
    @Override
    public void onClick(final View v) {
        IMoreListener listener = mMoreListener.get();
        if (listener == null) {
            return;
        }

        int id = v.getId();
        switch (id) {
            case R.id.btn_back:
                dismiss();
                break;

            //Board(涂鸭)
            case R.id.board_setNextTextFocusable:
                isNextTextFocusable = ((CheckBox) v).isChecked();
                break;
            case R.id.board_autoSelect:
                Boolean checked = ((CheckBox) v).isChecked();
                listener.onAutoSelect(checked);
                break;
            case R.id.board_nextText:
                String textContent = ((EditText) findViewById(R.id.et_next)).getText().toString();
                listener.onNextTextInput(textContent, isNextTextFocusable);
                break;
            case R.id.board_tipText:
                String tipContent = ((EditText) findViewById(R.id.et_tip)).getText().toString();
                listener.onTipTextInput(tipContent);
                break;
            case R.id.board_wipeText:
                String wipeContent = ((EditText) findViewById(R.id.et_wipe)).getText().toString();
                listener.onWipeNumInput(Integer.parseInt(wipeContent));
                break;
            case R.id.board_setDrawEnable:
                boolean setDrawEnable = ((CheckBox) v).isChecked();
                listener.onSetDrawEnable(setDrawEnable);
                break;

            case  R.id.board_setNickNameVisiable:
                boolean nickNameVisiable = ((CheckBox) v).isChecked();
                listener.onSetNickNameVisiable(nickNameVisiable);
                break;

            case R.id.board_SynDrawEnable:
                boolean syncDrawEnable = ((CheckBox) v).isChecked();
                listener.onSyncDrawEnable(syncDrawEnable);
                break;
            case R.id.board_multiTouch:
                boolean multiTouch = ((CheckBox) v).isChecked();
                listener.onMultiTouchEnable(multiTouch);
                mSettingData.isMultiTouch = multiTouch;
                break;

            case R.id.board_disableTouch:
                boolean disableTouch = ((CheckBox) v).isChecked();
                listener.onTouchEnable(!disableTouch);
                mSettingData.isDisableTouch = disableTouch;
                break;

            case R.id.board_segmentEraser:
                boolean segmentEraser = ((CheckBox) v).isChecked();
                listener.onSegmentEraser(segmentEraser);
                mSettingData.isSegmentEraser = segmentEraser;
                break;
            case R.id.board_snapshot:
                listener.onStartSnapshot();
                break;
            case R.id.board_setHandwritingEnable:
                boolean setHandwritingEnable = ((CheckBox) v).isChecked();
                listener.onSetHandwritingEnable(setHandwritingEnable);
                break;
            case R.id.cursor_yes:
                listener.onSetSystemCursorEnable(true);
                break;
            case R.id.cursor_no:
                listener.onSetSystemCursorEnable(false);
                break;
            case R.id.btn_SetToolType:
                int pos = ((Spinner) findViewById(R.id.sp_SetToolType)).getSelectedItemPosition();
                if (pos < mToolMap.length) {
                    int type = mToolMap[pos].type;
                    listener.onSetToolType(type);
                }
                break;

            case R.id.btn_SetGraphStyle:
                pos = ((Spinner) findViewById(R.id.sp_SetGraphStyle)).getSelectedItemPosition();
                if (pos < mGraphStyle.length) {
                    int type = mGraphStyle[pos].type;
                    listener.onSetGraphStyle(type);
                    mSettingData.graphStyle = type;
                }
                break;

            case R.id.btn_SetMathToolType:
                pos = ((Spinner) findViewById(R.id.sp_SetToolMathType)).getSelectedItemPosition();
                if (pos < mMathToolMap.length) {
                    int type = mMathToolMap[pos].type;
                    listener.onSetMathToolType(type);
                }
                break;

            case R.id.btn_SetMagicPen:
                pos = ((Spinner) findViewById(R.id.sp_SetMagicPen)).getSelectedItemPosition();
                if (pos < mMagicPenType.length) {
                    int type = mMagicPenType[pos].type;
                    listener.onSetMagicPen(type);
                }
                break;

            case R.id.btn_BrushThin:
                int BrushThin = ((SeekBar) findViewById(R.id.sk_BrushThin)).getProgress();
                listener.onBrushThin(BrushThin);
                break;

            case R.id.btn_SetTextSize:
                int SetTextSize = ((SeekBar) findViewById(R.id.sk_SetTextSize)).getProgress();
                listener.onSetTextSize(SetTextSize);
                break;

            case R.id.btn_SetTextHeight:
                int textHeight = ((SeekBar) findViewById(R.id.sk_SetTextHeight)).getProgress();
                listener.onSetTextHeight( ((float)textHeight) / 100.0f);
                break;

            case R.id.btn_SetEraserSize:
                int eraserSize = ((SeekBar) findViewById(R.id.sk_SetEraserSize)).getProgress();
                listener.onSetEraserSize(eraserSize);

            case R.id.btn_scaleBoard:
                int scaleBoard = ((SeekBar) findViewById(R.id.sk_scaleBoard)).getProgress();
                listener.onScale(scaleBoard);
                break;

            case R.id.board_16_9:
            case R.id.board_4_3: {
                boolean ischeck = ((RadioButton) v).isChecked();
                if (ischeck) {
                    String ration = ((RadioButton) v).getText().toString();
                    listener.onSetRatio(ration);
                }
            }
            break;

            case R.id.btn_fitMode: {
                int pos_sp_fitMode = ((Spinner) findViewById(R.id.sp_fitMode)).getSelectedItemPosition();
                if (pos_sp_fitMode < FitMode.length) {
                    int type = FitMode[pos_sp_fitMode].type;
                    listener.onSetFitMode(type);
                }
            }
            break;

            case R.id.btn_undo:
                listener.onUndo();
                break;

            case R.id.btn_redo:
                listener.onRedo();
                break;

            case R.id.btn_clear:
                listener.onClear();
                break;

            case R.id.btn_clearDraws:
                listener.onClearDraws();
                break;
            case R.id.btn_clearBackground:
                listener.onClearBackground();
                break;
            case R.id.btn_reset:
                listener.onReset();
                break;
            case R.id.btn_addElement:
                int pose = ((Spinner) findViewById(R.id.sp_addElement)).getSelectedItemPosition();
                if (pose < ELEMENT_URL.length) {
                    String value = ELEMENT_URL[pose].value;
                    listener.onAddElement(pose + 1, value);
                }
                break;

            case R.id.btn_setTextStyle:
                int postext = ((Spinner) findViewById(R.id.sp_setTextStyle)).getSelectedItemPosition();
                if (postext < TextStyle.length) {
                    int type = TextStyle[postext].type;
                    listener.onSetTextStyle(type);
                }
                break;
            case R.id.btn_selectTextColor:
            case R.id.btn_selectBackgroundColor:
            case R.id.btn_selectGlobalBackgroundColor:
            case R.id.btn_selectHighlightColor:
            case R.id.btn_selectBrushColor:
                int color = 0xffffffff;
                if (v.getId() == R.id.btn_selectBackgroundColor) {
                    color = mSettingData.BackgroundColor;
                }
                else if(v.getId() == R.id.btn_selectGlobalBackgroundColor) {
                    color = mSettingData.GlobalBackgroundColor;
                }
                else if(v.getId() == R.id.btn_selectTextColor) {
                    color = mSettingData.TextColor;
                }
                else if(v.getId() == R.id.btn_selectHighlightColor) {
                    color = mSettingData.highlightColor;
                }
                else if(v.getId() == R.id.btn_selectBrushColor) {
                    color = mSettingData.BrushColor;
                }
                if (this.activity != null) {
                    View parent = this.findViewById(android.R.id.content);
                    new ColorPickerPopup.Builder(this.activity.get())
                            .initialColor(color)
                            .enableAlpha(true)
                            .showIndicator(true)
                            .showValue(true)
                            .build().show(parent,new ColorPickerPopup.ColorPickerObserver() {
                        @Override
                        public void onColorPicked(int color) {
                            if (v.getId() == R.id.btn_selectBackgroundColor) {
                                mSettingData.BackgroundColor = color;
                            }
                            else if(v.getId() == R.id.btn_selectGlobalBackgroundColor) {
                                mSettingData.GlobalBackgroundColor = color;
                            }
                            else if(v.getId() == R.id.btn_selectTextColor) {
                                mSettingData.TextColor = color;
                            }
                            else if(v.getId() == R.id.btn_selectHighlightColor) {
                                mSettingData.highlightColor = color;
                            }
                            else if(v.getId() == R.id.btn_selectBrushColor) {
                                mSettingData.BrushColor = color;
                            }
                            setBtnColor((Button) v, color);
                        }

                    });
                }

                break;
            case R.id.btn_setTextColor:
                listener.onSetTextColor(mSettingData.TextColor);
                break;
            case R.id.btn_setGlobalBackgroundColor:
                listener.onSetGlobalBackgroundColore(mSettingData.GlobalBackgroundColor);
                break;
            case R.id.btn_setBackgroundColor:
                listener.onSetBackgroundColore(mSettingData.BackgroundColor);
                break;
            case R.id.btn_setHighlightColor:
                listener.onSetHighlightColor(mSettingData.highlightColor);
                break;
            case R.id.btn_setBrushColor:
                listener.onSetBrushColor(mSettingData.BrushColor);
                break;
            case R.id.btn_setBackgroundImage:
                int pos_bgImgBk = ((Spinner) findViewById(R.id.sp_setBackgroundImage)).getSelectedItemPosition();
                if (pos_bgImgBk < BACKGROUND_IMAGE.length) {
                    final String path = BACKGROUND_IMAGE[pos_bgImgBk].key;
                    listener.onSetBackgroundImage(path);
                }
//                Object pos4 = ((Spinner) findViewById(R.id.sp_setBackgroundImage)).getSelectedItem();
//                if (pos4 != null && pos4 instanceof String) {
//                    final String path = "file:///android_asset/img/" + (String) pos4;
//                    listener.onSetBackgroundImage(path);
//                }
                break;
            case R.id.btn_set_wipe_type:
                int wipePos = ((Spinner) findViewById(R.id.sp_set_wipe_type)).getSelectedItemPosition();
                if (wipePos < WipeStyle.length) {
                    int type = WipeStyle[wipePos].type;
                    listener.setWipeType(type);
                }
                break;
            case R.id.btn_setBackgroundH5:
                int pos_h5bk = ((Spinner) findViewById(R.id.sp_setBackgroundH5)).getSelectedItemPosition();
                if (pos_h5bk < H5_BK_URL.length) {
                    final String path = H5_BK_URL[pos_h5bk].key;
                    listener.onSetBackgroundH5(path);
                }
                break;
            case R.id.btn_setPermission:
                listener.onSetPermission();
                break;

            //Board(白板)
            case R.id.btn_prevBoard:
                listener.onPrevBoard();
                break;

            case R.id.btn_nextBoard:
                listener.onNextBoard();
                break;

            case R.id.btn_prevStep:
                listener.onPrevStep();
                break;

            case R.id.btn_nextStep:
                listener.onNextStep();
                break;

            case R.id.btn_addBoard:
                EditText editText = findViewById(R.id.addBoardIndex);
                String input = editText.getText().toString();
                if (input.length() == 0) {
                    listener.showToast("新增白板索引号不能为空");
                    return;
                }
                try {
                    int value = Integer.parseInt(input);
                    if (value >= 0) {
                        // 输入值为大于等于0的整数
                        // 在这里执行相应的操作
                        listener.onAddBoard(null, value);
                    } else {
                        Toast.makeText(getContext(), "新增白板索引号输入无效", Toast.LENGTH_LONG);
                    }
                } catch (NumberFormatException e) {
                    // 输入值无法解析为整数
                    // 在这里执行相应的操作
                }

                break;

            case R.id.btn_deleteBoard: {
                Spinner deleteboard = findViewById(R.id.sp_deleteBoard);

                Object objdeleteboard = deleteboard.getSelectedItem();
                if (objdeleteboard != null && objdeleteboard instanceof String) {
                    String boardid = (String) objdeleteboard;
                    listener.onDeleteBoard(boardid);
//                        boardArray.remove(boardid);
                }
            }
            break;

            case R.id.btn_gotoBoard:
                Object objgotoboard = ((Spinner) findViewById(R.id.sp_gotoBoard)).getSelectedItem();
                if (objgotoboard != null && objgotoboard instanceof String) {
                    listener.onGotoBoard((String) objgotoboard);
                }
                break;

            //Board(文件)
            case R.id.btn_addFile:
//                int pos5 = ((Spinner) findViewById(R.id.sp_addFile)).getSelectedItemPosition();
//                if (pos5 >= 0 && pos5 < H5_PPT_URL.length) {
//                    TEduBoardController.TEduBoardTranscodeFileResult result = H5_PPT_URL[pos5];
//                    listener.onTransCodeFile(result);
//                }
                listener.onTransCodeFile(null);
                break;

            case R.id.btn_addH5File:
//                int h5File = ((Spinner) findViewById(R.id.sp_addH5File)).getSelectedItemPosition();
//                if (h5File >= 0 && h5File < H5_FILE_URL.length) {
//                    String url = H5_FILE_URL[h5File].key;
//
//                }
                listener.onAddH5File("");
                break;

            case R.id.btn_addImagesFile: {
                List<String> urls = Arrays.asList(Images_URL);
                listener.onAddImagesFile(urls);
            }

            break;

            case R.id.btn_deleteFile:
                Object objTitle = ((Spinner) findViewById(R.id.sp_deleteFile)).getSelectedItem();
                if (objTitle != null && objTitle instanceof String) {
                    final String title = (String) objTitle;
                    for (TEduBoardController.TEduBoardFileInfo file : mSettingData.files) {
                        if (title.equals(file.title)) {
                            listener.onDeleteFile(file.fileId);
                            return;
                        }
                    }
                }
                break;

            case R.id.btn_switchFile:
                Object pos7 = ((Spinner) findViewById(R.id.sp_switchFile)).getSelectedItem();
                if (pos7 != null && pos7 instanceof String) {
                    String title = (String) pos7;

                    for (TEduBoardController.TEduBoardFileInfo file : mSettingData.files) {
                        if (title.equals(file.title)) {
                            listener.onGotoFile(file.fileId);
                            return;
                        }
                    }

                    Toast.makeText(getContext(), "file is not exist.", Toast.LENGTH_LONG);
                }
                break;
            case R.id.btn_addWatermark:
                listener.onAddWatermark();
                break;
            case R.id.btn_addVideoFile:
                listener.onAddVideo();
                break;
            case R.id.btn_playPPTVideo:
                listener.onPlayPPPTVideo();
                break;
            case R.id.btn_playPPTAudio:
                listener.onPlayPPPTAudio();
                break;
            case R.id.btn_pausePPTVideo:
                listener.onPausePPPTVideo();
                break;
            case R.id.btn_pausePPTAudio:
                listener.onPausePPPTAudio();
                break;
            case R.id.btn_exportInLocalMode:
                listener.onExportInLocalMode();
                break;
            case R.id.btn_importInLocalMode:
                listener.onImportInLocalMode();
                break;
            case R.id.btn_exportInLocalModeWithFilter:
                listener.onExportInLocalModeWithFilter();
                break;
            case R.id.btn_importInLocalModeWithFilter:
                listener.onImportInLocalModeWithFilter();
                break;
            case R.id.btn_hideElements:
                listener.onHideElements();
                break;
            case R.id.btn_showElements:
                listener.onShowElements();
                break;
            case R.id.btn_addAudio:
                int pos9 = ((Spinner) findViewById(R.id.sp_addAudio)).getSelectedItemPosition();
                if (pos9 >= 0 && pos9 < AudioRes_URL.length) {
                    final String url = AudioRes_URL[pos9].key;
                    final String title = AudioRes_URL[pos9].value;
                    listener.onAddAudio(url, title);
                }
                break;

            case R.id.btn_video_ctrl_enalbe:
                boolean video_ctrl_enalbe = ((CheckBox) v).isChecked();
                listener.onShowVideoCtrl(video_ctrl_enalbe);
                break;
            case R.id.board_audio_play:
                listener.onPlayAudio();
                break;
            case R.id.board_audio_pause:
                listener.onPauseAudio();
                break;
            case R.id.btn_reload:
                listener.onSyncAndReload();
                break;
            case R.id.btn_add_domain:
                listener.onAddBackupDomain();
                break;
            case R.id.btn_remove_domain:
                listener.onRemoveBackupDomain();
                break;

            case R.id.btn_addtoclassgroup:
                EditText groupEt = findViewById(R.id.et_groupId1);
                EditText userEt = findViewById(R.id.et_userId1);

                String groupId = groupEt.getText().toString();
                String userId = userEt.getText().toString();

                listener.onAddBoardToClassGroup(groupId, userId);

                break;
            case R.id.btn_addusertoclassgroup:

                EditText groupEt2 = findViewById(R.id.et_groupId2);
                EditText userEt2 = findViewById(R.id.et_userId2);

                String groupId2 = groupEt2.getText().toString();
                String userId2 = userEt2.getText().toString();

                listener.onAddUserToClassGroup(groupId2, userId2);

                break;
            case R.id.btn_getallclassgroupids:
                listener.onGetAllClassGroupIds();
                break;
            case R.id.btn_getclassgroupenable:
                listener.onGetClassGroupEnable();
                break;
            case R.id.btn_getclassgroupbyuserid:
                EditText userEt3 = findViewById(R.id.et_userId3);
                String userId3 = userEt3.getText().toString();
                listener.onGetClassGroupIdByUserId(userId3);
                break;
            case R.id.btn_getClassGroupInfoByGroupId:
                EditText groupIdEt4 = findViewById(R.id.et_groupid4);
                String groupId4 = groupIdEt4.getText().toString();
                listener.onGetClassGroupInfoByGroupId(groupId4);
                break;
            case R.id.btn_gotoClassGroupBoard:
                EditText boardIdEt5 = findViewById(R.id.et_boardid4);
                String boardId5 = boardIdEt5.getText().toString();
                listener.onGotoClassGroupBoard(boardId5);
                break;
            case R.id.btn_removeBoardInClassGroup:
                EditText groupIdEt5 = findViewById(R.id.et_groupid5);
                String groupId5 = groupIdEt5.getText().toString();
                EditText boardIdEt6 = findViewById(R.id.et_boardid5);
                String boardId6 = boardIdEt6.getText().toString();

                listener.onRemoveBoardInClassGroup(groupId5, boardId6);
                break;
            case R.id.btn_removeClassGroup:
                EditText groupIdEt6 = findViewById(R.id.et_groupid6);
                String groupId6 = groupIdEt6.getText().toString();

                listener.onRemoveClassGroup(groupId6);
                break;
            case R.id.btn_removeUserInClassGroup:
                EditText groupEt7 = findViewById(R.id.et_groupid7);
                EditText userEt7 = findViewById(R.id.et_userid7);

                String groupId7 = groupEt7.getText().toString();
                String userId7 = userEt7.getText().toString();

                listener.onRemoveUserInClassGroup(groupId7, userId7);
                break;
            case R.id.btn_resetClassGroup:
                listener.onResetClassGroup();
                break;
            case R.id.btn_setClassGroup:
                EditText et_groupid8 = findViewById(R.id.et_groupid8);
                EditText et_boardid8 = findViewById(R.id.et_boardid8);
                EditText et_userid8 = findViewById(R.id.et_userid8);
                EditText et_title8 = findViewById(R.id.et_title8);
                EditText et_currentboardid8 = findViewById(R.id.et_currentboardid8);

                String groupStr = et_groupid8.getText().toString();
                String boardStr = et_boardid8.getText().toString().trim();
                String userStr = et_userid8.getText().toString().trim();
                String titleStr = et_title8.getText().toString();
                String currentboardStr = et_currentboardid8.getText().toString();
                List<String> boardList = new ArrayList<>();
                List<String> userList = new ArrayList<>();
                boardList=Arrays.asList(boardStr.split(","));
                userList =Arrays.asList(userStr.split(","));
                
                listener.onSetClassGroup(groupStr,boardList,userList,titleStr,currentboardStr);
                break;
            case R.id.btn_setClassGroupEnable:
                EditText et_enable9 = findViewById(R.id.et_enable9);
                String enable = et_enable9.getText().toString();
                Boolean isEnable=Boolean.parseBoolean(enable);
                listener.onSetClassGroupEnable(isEnable);
                break;
            case R.id.btn_setClassGroupTitle:
                EditText et_groupid10 = findViewById(R.id.et_groupid10);
                EditText et_title10 = findViewById(R.id.et_title10);

                String group10 = et_groupid10.getText().toString();
                String title10 = et_title10.getText().toString();

                listener.onSetClassGroupTitle(group10, title10);
                break;
        }
    }

}
